@@ -6,7 +6,7 @@ This module contains implementations for the Constraint{s} class.
 """
 
 import re
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from itertools import product
 from typing import Any, Sequence, Union
 
@@ -226,12 +226,12 @@ class Constraints:
     A constraint container used for storing multiple constraint arrays.
     """
 
-    labels: Dataset = Dataset()
-    coeffs: Dataset = Dataset()
-    vars: Dataset = Dataset()
-    sign: Dataset = Dataset()
-    rhs: Dataset = Dataset()
-    blocks: Dataset = Dataset()
+    labels: Dataset = field(default_factory=Dataset)
+    coeffs: Dataset = field(default_factory=Dataset)
+    vars: Dataset = field(default_factory=Dataset)
+    sign: Dataset = field(default_factory=Dataset)
+    rhs: Dataset = field(default_factory=Dataset)
+    blocks: Dataset = field(default_factory=Dataset)
     model: Any = None  # Model is not defined due to circular imports
 
     dataset_attrs = ["labels", "coeffs", "vars", "sign", "rhs"]
@@ -671,12 +671,14 @@ class AnonymousConstraint:
 
         # test output type
         output = rule(model, *[c.values[0] for c in coords.values()])
-        if not isinstance(output, AnonymousScalarConstraint):
+        if not isinstance(output, AnonymousScalarConstraint) and not output is None:
             msg = f"`rule` has to return AnonymousScalarConstraint not {type(output)}."
             raise TypeError(msg)
 
         combinations = product(*[c.values for c in coords.values()])
-        cons = [rule(model, *coord) for coord in combinations]
+        placeholder_lhs = expressions.ScalarLinearExpression((np.nan,), (-1,))
+        placeholder = AnonymousScalarConstraint(placeholder_lhs, "=", np.nan)
+        cons = [rule(model, *coord) or placeholder for coord in combinations]
         exprs = [con.lhs for con in cons]
 
         lhs = expressions.LinearExpression._from_scalarexpression_list(exprs, coords)
