@@ -19,12 +19,17 @@ from xarray import DataArray, Dataset
 
 from linopy import solvers
 from linopy.common import best_int, replace_by_map
-from linopy.constraints import AnonymousConstraint, Constraints
+from linopy.constraints import (
+    AnonymousConstraint,
+    AnonymousScalarConstraint,
+    Constraints,
+)
 from linopy.eval import Expr
-from linopy.expressions import LinearExpression
-from linopy.io import to_block_files, to_file, to_netcdf
+from linopy.expressions import LinearExpression, ScalarLinearExpression
+from linopy.io import to_block_files, to_file, to_gurobipy, to_highspy, to_netcdf
+from linopy.matrices import MatrixAccessor
 from linopy.solvers import available_solvers
-from linopy.variables import Variable, Variables
+from linopy.variables import ScalarVariable, Variable, Variables
 
 logger = logging.getLogger(__name__)
 
@@ -67,6 +72,7 @@ class Model:
         "_force_dim_names",
         "_solver_dir",
         "solver_model",
+        "matrices",
     )
 
     def __init__(self, solver_dir=None, chunk=None, force_dim_names=False):
@@ -114,6 +120,8 @@ class Model:
         self._force_dim_names = bool(force_dim_names)
         self._solver_dir = Path(gettempdir() if solver_dir is None else solver_dir)
 
+        self.matrices = MatrixAccessor(self)
+
     @property
     def variables(self):
         """
@@ -508,6 +516,9 @@ class Model:
             rule = lhs
             lhs = AnonymousConstraint.from_rule(self, rule, coords)
 
+        if isinstance(lhs, AnonymousScalarConstraint):
+            lhs = lhs.to_anonymous_constraint()
+
         if isinstance(lhs, AnonymousConstraint):
             if sign is not None or rhs is not None:
                 raise ValueError(
@@ -526,7 +537,7 @@ class Model:
 
         if isinstance(lhs, (list, tuple)):
             lhs = self.linexpr(*lhs)
-        elif isinstance(lhs, Variable):
+        elif isinstance(lhs, (Variable, ScalarVariable, ScalarLinearExpression)):
             lhs = lhs.to_linexpr()
         assert isinstance(lhs, LinearExpression)
 
@@ -1024,6 +1035,7 @@ class Model:
         basis_fn=None,
         warmstart_fn=None,
         keep_files=False,
+        sanitize_zeros=True,
         remote=None,
         **solver_options,
     ):
@@ -1066,6 +1078,10 @@ class Model:
             Whether to keep all temporary files like lp file, solution file.
             This argument is ignored for the logger file `log_fn`. The default
             is False.
+        sanitize_zeros : bool, optional
+            Whether to set terms with zero coeffficient as missing.
+            This will remove unneeded overhead in the lp file writing.
+            The default is True.
         remote : linopy.remote.RemoteHandler
             Remote handler to use for solving model on a server. Note that when
             solving on a rSee
@@ -1089,6 +1105,7 @@ class Model:
                 basis_fn=basis_fn,
                 warmstart_fn=warmstart_fn,
                 keep_files=keep_files,
+                sanitize_zeros=sanitize_zeros,
                 **solver_options,
             )
 
@@ -1112,6 +1129,9 @@ class Model:
         problem_fn = self.get_problem_file(problem_fn)
         solution_fn = self.get_solution_file(solution_fn)
 
+        if sanitize_zeros:
+            self.constraints.sanitize_zeros()
+
         try:
             func = getattr(solvers, f"run_{solver_name}")
             res = func(
@@ -1198,4 +1218,8 @@ class Model:
 
     to_file = to_file
 
+    to_gurobipy = to_gurobipy
+
+    to_highspy = to_highspy
+
     to_block_files = to_block_files
